import logging
from imapclient import IMAPClient

LOG_FILE_PATH = '/var/log/cyops/cyops-integrations/imap/listener.log'

logging.basicConfig(filename=LOG_FILE_PATH, level=logging.INFO,
                    format='%(asctime)s %(levelname)s %(module)s %(funcName)s(): %(message)s')

logger = logging.getLogger(__name__)

def _select_folder(client, folder):
    """
    Selects a folder on the IMAP server

   :param IMAPClient client: The client object containing connection info
   :param str folder: The folder to select

   :return: a dict containing information about the folder
   :rtype: dict
    """
    return client.select_folder(folder)


def _make_imap_client(host, port, username, password, ssl):
    """
    Creates the IMAP client that contains connection information.

   :param str host: imap host
   :param str port: imap port
   :param str username: username for email account
   :param str password: password for email account

   :return: The IMAP client with an active connection into the IMAP server
   :rtype: IMAPClient
    """
    imap_client_args = {
        'host': host,
        'port': port,
        'ssl': True,
        'use_uid': True,
        'timeout': 5,
    }
    client = IMAPClient(**imap_client_args)
    client.login(username, password)
    return client

def logout_client (client):
    try:
        client.logout()
    except Exception as e:
        logger.exception("Message: IMAP client logout unsuccessfull %s", str(e))
    return